This data set contains the list of all French departments. It can be joined with the french_regions or the french_cities data set. The data set was extracted from the INSEE open data in November 2025. These data are distributed under the French "Open Licence".
french_departmentsA data.frame with 101 rows and 3 columns
The code of the department in the official geographical code of 2025 (OGC)
The code of the region of the city in the OGC (see french_regions)
The name of the department
french_cities and french_regions