Skip to contents

The function reports the potentia of each spatial interaction model of its sim_list parameter (see sim_potential())

Usage

grid_sim_potential(sim, ...)

Arguments

sim

a collection of spatial interaction models, an object of class sim_list

...

additional parameters

Value

a vector of numbers of iteration, one per spatial interaction model

Details

Notice that sim_potential() is generic and can be applied directly to sim_list objects. The current function is provided to be explicit in R code about what is a unique model and what is a collection of models (using function names that start with "grid_")

Examples

distances <- french_cities_distances[1:15, 1:15] / 1000 ## convert to km
production <- log(french_cities$population[1:15])
attractiveness <- log(french_cities$area[1:15])
all_flows <- grid_blvim(
  distances, production, c(1.1, 1.25, 1.5),
  c(1, 2, 3, 4) / 500, attractiveness,
  epsilon = 0.1,
  bipartite = FALSE,
  iter_max = 750
)
grid_sim_potential(all_flows)
#>  [1] 647.6623 662.1504 686.9198 533.1884 550.9465 572.8724 447.2027 464.6454
#>  [9] 499.9672 395.3647 405.9855 432.1033