Returns a full diagnostic of the algorithm used to build a spatial interaction model
Source:R/sim.R
sim_diagnostic.RdSome spatial interaction models are the result of an iterative calculation,
see for instance blvim(). This function returns a diagnostic object that
gives details about the behaviour of the iterative algorithm.
Examples
distances <- french_cities_distances[1:10, 1:10] / 1000 ## convert to km
production <- log(french_cities$population[1:10])
attractiveness <- log(french_cities$area[1:10])
model <- static_blvim(distances, production, 1.5, 1 / 250, attractiveness)
sim_diagnostic(model)
#> Static spatial interaction model