This function returns a list with parameters used to tweak the gradient
algorithms used in blvim(). These parameters control the line search
algorithm which is a standard backtracking method with Armijo stopping
criterion.
Usage
blvim_gradient_control(
rho_init = 0.5,
shrink = 0.5,
sufficient_increase = 1e-05,
ls_iter_max = 50
)References
Armijo, Larry (1966), "Minimization of functions having Lipschitz continuous first partial derivatives", Pacific J. Math. 16 (1): 1–3 doi:10.2140/pjm.1966.16.1